@@ -26,24 +26,27 @@
 
 """Run the specified tests after all the others."""
 
+from __future__ import annotations
+
 import argparse
+import dataclasses
 import os
 import re
 import subprocess
 import sys
 
-from typing import List, NamedTuple, Optional  # noqa: H301
+
+VERSION = "0.1.2"
 
 
-VERSION = "0.1.1"
-
-
-class Config(NamedTuple):
+@dataclasses.dataclass(frozen=True)
+class Config:
     """Runtime configuration for the tox_delay tool."""
 
-    envlist: List[str]
-    parallel: Optional[str]
-    tox_args: List[str]
+    envlist: list[str]
+    ignore: list[str]
+    parallel: str | None
+    tox_args: list[str]
 
 
 def parse_args() -> Config:
@@ -64,6 +67,7 @@ def parse_args() -> Config:
         type=str,
         help="the environments to delay",
     )
+    parser.add_argument("-i", "--ignore", type=str, help="the environments to not run at all")
     parser.add_argument(
         "tox_args",
         type=str,
@@ -74,7 +78,7 @@ def parse_args() -> Config:
     args = parser.parse_args()
 
     if args.features:
-        print(f"Features: tox-delay={VERSION} parallel=1.0")
+        print(f"Features: tox-delay={VERSION} ignore=1.0 longopts=1.0 parallel=1.0")
         sys.exit(0)
 
     if args.envlist is None:
@@ -82,6 +86,7 @@ def parse_args() -> Config:
 
     return Config(
         envlist=args.envlist.split(","),
+        ignore=args.ignore.split(",") if args.ignore else [],
         parallel=args.parallel,
         tox_args=args.tox_args,
     )
@@ -93,7 +98,9 @@ def main() -> None:
     tox_cmd = [sys.executable, "-m", "tox"]
 
     skip_env = dict(os.environ)
-    skip_env["TOX_SKIP_ENV"] = "^" + "|".join(re.escape(testenv) for testenv in cfg.envlist) + "$"
+    skip_env["TOX_SKIP_ENV"] = (
+        "^" + "|".join(re.escape(testenv) for testenv in cfg.ignore + cfg.envlist) + "$"
+    )
     parallel_opts = ["-p", cfg.parallel] if cfg.parallel is not None else []
     subprocess.check_call(tox_cmd + parallel_opts + cfg.tox_args, env=skip_env)
 
