@@ -26,7 +26,7 @@
 
 set -e
 
-tox_delay_version='0.1.1'
+tox_delay_version='0.1.2'
 
 version()
 {
@@ -36,10 +36,11 @@ version()
 usage()
 {
 	cat <<'EOUSAGE'
-Usage:	tox-delay [-p value] -e envlist -- [tox options]
+Usage:	tox-delay [-i envlist] [-p value] -e envlist -- [tox options]
 	tox-delay --features | -h | --help | -V | --version
 
 	-e	specify the list of environments to delay the run for
+	-i	specify the list of environments to not run at all
 	-h	display program usage information and exit
 	-p	run the first batch of environments in parallel
 	-V	display program version information and exit
@@ -50,7 +51,8 @@ EOUSAGE
 
 features()
 {
-	echo "Features: tox-delay=$tox_delay_version parallel=1.0"
+	echo "Features: tox-delay=$tox_delay_version ignore=1.0" \
+	    "longopts=0.1 parallel=1.0"
 }
 
 escape_name()
@@ -82,9 +84,9 @@ build_escaped_envlist()
 	printf -- '%s\n' "$res"
 }
 
-unset show_features show_help show_version envlist parallel
+unset show_features show_help show_version envlist ignorelist parallel
 
-while getopts 'e:hp:V-:' o; do
+while getopts 'e:hi:p:V-:' o; do
 	case "$o" in
 		e)
 			envlist="$OPTARG"
@@ -94,6 +96,10 @@ while getopts 'e:hp:V-:' o; do
 			show_help=1
 			;;
 
+		i)
+			ignorelist="$OPTARG"
+			;;
+
 		p)
 			parallel="$OPTARG"
 			;;
@@ -143,7 +149,7 @@ if [ -z "$envlist" ]; then
 	exit 1
 fi
 
-escaped="$(build_escaped_envlist "$envlist")"
+escaped="$(build_escaped_envlist "${ignorelist+$ignorelist,}$envlist")"
 env TOX_SKIP_ENV="$escaped" tox ${parallel+-p "$parallel"} "$@"
 
 tox -e "$envlist" "$@"
