@@ -26,15 +26,16 @@
 
 """Run tox-delay from a temporary directory, examine its output."""
 
+from __future__ import annotations
+
 import argparse
+import dataclasses
 import os
 import pathlib
 import subprocess
 import sys
 import tempfile
 
-from typing import Dict, List, NamedTuple, Optional, Tuple  # noqa: H301
-
 import feature_check
 import utf8_locale
 
@@ -67,13 +68,14 @@ commands =
 )
 
 
-class Config(NamedTuple):
+@dataclasses.dataclass(frozen=True)
+class Config:
     """Runtime configuration for the tox-delay functional test."""
 
-    executable: Optional[pathlib.Path]
+    executable: pathlib.Path | None
     python: pathlib.Path
-    python_env: Dict[str, str]
-    utf8_env: Dict[str, str]
+    python_env: dict[str, str]
+    utf8_env: dict[str, str]
 
 
 def parse_args() -> Config:
@@ -201,9 +203,10 @@ def check_tox_output(
     cfg: Config,
     tempd: pathlib.Path,
     tox: str,
-    envlist: List[Tuple[str, str]],
+    envlist: list[tuple[str, str]],
     *,
-    order: Optional[List[Tuple[str, str]]] = None,
+    ignore: list[tuple[str, str]] | None = None,
+    order: list[tuple[str, str]] | None = None,
     parallel: bool = False,
 ) -> None:
     """Run tox or tox-delay, check its output."""
@@ -216,16 +219,17 @@ def check_tox_output(
         tox_cmd = [str(cfg.executable)]
         tox_env = cfg.utf8_env
 
-    def cmdline(args: Optional[List[str]] = None) -> List[str]:
+    def cmdline(args: list[str] | None = None) -> list[str]:
         """Build the command line to test."""
         return (
             tox_cmd
             + ["-e", envstr]
+            + (["-i", ",".join(item[0] for item in ignore)] if ignore is not None else [])
             + (["-p", "all"] if parallel else [])
             + (["--"] + args if args is not None else [])
         )
 
-    def check_output(args: Optional[List[str]] = None) -> None:
+    def check_output(args: list[str] | None = None) -> None:
         """Run the command and check its output."""
         print(
             f"\nRunning {tox} for {envstr}"
@@ -308,6 +312,17 @@ def test_tox_delay(cfg: Config, tempd: pathlib.Path, parallel: bool) -> None:
         parallel=parallel,
     )
 
+    print("Ignore some environments")
+    check_tox_output(
+        cfg,
+        tempd,
+        "tox_delay",
+        [TOX_ENVLIST_ORDERED[2]],
+        order=[TOX_ENVLIST_ORDERED[0], TOX_ENVLIST_ORDERED[2]],
+        parallel=parallel,
+        ignore=[TOX_ENVLIST_ORDERED[1], TOX_ENVLIST_ORDERED[3]],
+    )
+
 
 def main() -> None:
     """Main program: parse command-line options, run things."""
